@@ -260,6 +260,11 @@ BIMI_TAGS = OrderedDict(
         "Indicator file. The only supported transport "
         "is HTTPS.",
     ),
+    lps=OrderedDict(
+        name="Local-Part Selectors",
+        default="",
+        description="A comma separated list of allowed Local-Part Selectors",
+    ),
     avp=OrderedDict(
         name="Avatar Preference",
         required=False,
@@ -267,7 +272,7 @@ BIMI_TAGS = OrderedDict(
         description="For mail sent to those mailbox providers that both participate in BIMI and "
         "support the display of personal avatars, this flag is a way for the Domain "
         "Owner to express its preference as to whether to show the BIMI logo or the "
-        "personal avatar.",
+        "personal avatar. Options are personal or brand",
     ),
 )
 
@@ -510,6 +515,7 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
         if "all candidates exhausted with no interior errors" in e_str:
             e_str = "The certificate was not issued by a recognized Mark Verifying Authority (MVA)."
             validation_errors.append(e_str)
+            valid = False
     not_valid_before_timestamp = vmc.not_valid_before_utc.strftime("%Y-%m-%d %H:%M:%SZ")
     not_valid_after_timestamp = vmc.not_valid_after_utc.strftime("%Y-%m-%d %H:%M:%SZ")
     not_yet_valid = datetime.now(timezone.utc) < vmc.not_valid_before_utc
@@ -536,7 +542,7 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
     if domain is not None:
         base_domain = get_base_domain(domain).encode("utf-8").decode("unicode_escape")
         if cert_domains is not None:
-            if base_domain not in cert_domains:
+            if domain not in cert_domains and base_domain not in cert_domains:
                 plural = "domain" if len(cert_domains) == 1 else "domains"
                 cert_domains = ". ".join(cert_domains)
                 validation_errors.append(
@@ -629,11 +635,11 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
         if logotype is not None:
             metadata["logotype_sha256"] = hashlib.sha256(logotype).hexdigest()
         metadata["warnings"] = warnings
-        metadata["Validation_errors"] = validation_errors
+        metadata["validation_errors"] = validation_errors
     except Exception as e:
         validation_errors.append(str(e))
         metadata["valid"] = False
-        metadata["Validation_errors"] = validation_errors
+        metadata["validation_errors"] = validation_errors
     return metadata
 
 
@@ -644,6 +650,7 @@ def _query_bimi_record(
     nameservers: list[str] = None,
     resolver: dns.resolver.Resolver = None,
     timeout: float = 2.0,
+    timeout_retries: int = 2,
 ):
     """
     Queries DNS for a BIMI record
@@ -655,6 +662,7 @@ def _query_bimi_record(
         resolver (dns.resolver.Resolver): A resolver object to use for DNS
                                           requests
         timeout (float): number of seconds to wait for a record from DNS
+        timeout_retries (int): The number of times to reattempt a query after a timeout
 
     Returns:
         str: A record string or None
@@ -668,7 +676,12 @@ def _query_bimi_record(
 
     try:
         records = query_dns(
-            target, "TXT", nameservers=nameservers, resolver=resolver, timeout=timeout
+            target,
+            "TXT",
+            nameservers=nameservers,
+            resolver=resolver,
+            timeout=timeout,
+            timeout_retries=timeout_retries,
         )
         for record in records:
             if record.startswith(txt_prefix):
@@ -724,6 +737,7 @@ def query_bimi_record(
     nameservers: list[str] = None,
     resolver: dns.resolver.Resolver = None,
     timeout: float = 2.0,
+    timeout_retries: int = 2,
 ) -> OrderedDict:
     """
     Queries DNS for a BIMI record
@@ -735,6 +749,7 @@ def query_bimi_record(
         resolver (dns.resolver.Resolver): A resolver object to use for DNS
                                           requests
         timeout (float): number of seconds to wait for a record from DNS
+        timeout_retries (int): The number of times to reattempt a query after a timeout
 
     Returns:
         OrderedDict: An ``OrderedDict`` with the following keys:
@@ -759,10 +774,16 @@ def query_bimi_record(
         nameservers=nameservers,
         resolver=resolver,
         timeout=timeout,
+        timeout_retries=timeout_retries,
     )
     try:
         root_records = query_dns(
-            domain, "TXT", nameservers=nameservers, resolver=resolver, timeout=timeout
+            domain,
+            "TXT",
+            nameservers=nameservers,
+            resolver=resolver,
+            timeout=timeout,
+            timeout_retries=timeout_retries,
         )
         for root_record in root_records:
             if root_record.startswith("v=BIMI1"):
@@ -774,7 +795,11 @@ def query_bimi_record(
 
     if record is None and domain != base_domain:
         record = _query_bimi_record(
-            base_domain, nameservers=nameservers, resolver=resolver, timeout=timeout
+            base_domain,
+            nameservers=nameservers,
+            resolver=resolver,
+            timeout=timeout,
+            timeout_retries=timeout_retries,
         )
         location = base_domain
     if record is None:
@@ -934,6 +959,11 @@ def parse_bimi_record(
                 raise BIMISyntaxError(
                     f"Acceptable avp tag values are personal or brand, not {tag_value}"
                 )
+        elif tag == "lps":
+            tag_value = tag_value.split(",")
+            for i in range(len(tag_value)):
+                tag_value[i] = tag_value[i].lower()
+
     if parsed_dmarc_record and not tags["l"] == "":
         if not parsed_dmarc_record["valid"]:
             warnings.append(
@@ -982,6 +1012,7 @@ def check_bimi(
     nameservers: list[str] = None,
     resolver: dns.resolver.Resolver = None,
     timeout: float = 2.0,
+    timeout_retries: int = 2,
 ) -> OrderedDict:
     """
     Returns a dictionary with a parsed BIMI record or an error.
@@ -1001,6 +1032,7 @@ def check_bimi(
         resolver (dns.resolver.Resolver): A resolver object to use for DNS
                                           requests
         timeout (float): number of seconds to wait for an answer from DNS
+        timeout_retries (int): The number of times to reattempt a query after a timeout
 
     Returns:
         OrderedDict: An ``OrderedDict`` with the following keys:
